@@ -6,15 +6,20 @@ and return batched results.
 
 """
 from .resize import imresize
-from .functions import fspecial_gauss, imfilter, dct2d, conv2d, fitweibull
+from .functions import *
 from .scfpyr_util import SCFpyr_PyTorch
 
 __all__ = [
     'imresize',
-    'fspecial_gauss',
+    'fspecial',
     'SCFpyr_PyTorch',
     'imfilter',
     'dct2d',
     'conv2d',
+    'filter2',
     'fitweibull',
+    'nancov',
+    'nanmean',
+    'im2col',
+    'blockproc',
 ]
